@@ -108,7 +108,7 @@ class DB:
   Method to insert [dict] multiple data into the database.
   Data inserted as a list and ids are returned (print).
   """
-  def insertMany(self, data: list):
+  def insertMany(self, data):
     mycol = DB.__createCol(self)
     x = mycol.insert_many(data)
     return f"Inserted datas with ids: {x.inserted_ids}"
